#
# spec file for package python-fastcluster
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-fastcluster
Version:        1.1.26
Release:        bp155.2.13
Summary:        Hierarchical clustering routines for Python
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/dmuellner/fastcluster
Source:         https://files.pythonhosted.org/packages/source/f/fastcluster/fastcluster-%{version}.tar.gz
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module nose}
BuildRequires:  %{python_module numpy-devel >= 1.9}
BuildRequires:  %{python_module scipy}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  python-rpm-macros
Requires:       python-numpy
Requires:       python-scipy
%python_subpackages

%description
This library provides Python functions for hierarchical clustering.
It generates hierarchical clusters from distance matrices or from
vector data.

Part of this module is intended to replace the functions
linkage, single, complete, average, weighted, centroid, median, ward
in the module scipy.cluster.hierarchy with the same functionality but
much faster algorithms. Moreover, the function 'linkage_vector'
provides memory-efficient clustering for vector data.

The interface is very similar to MATLAB's Statistics Toolbox API to
make code easier to port from MATLAB to Python/Numpy. The core
implementation of this library is in C++ for efficiency.

%package -n %{name}-doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
Provides:       %{python_module fastcluster-doc = %{version}}

%description -n %{name}-doc
Documentation and help files for %{name}.

%prep
%setup -q -n fastcluster-%{version}
sed -i 's/\r$//' CITATION.txt
sed -i 's/\r$//' NEWS.txt
sed -i 's/\r$//' README.txt

%build
export CFLAGS="%{optflags}"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
export LANG=en_US.UTF-8
%python_exec setup.py test

%files %{python_files}
%license COPYING.txt
%doc CITATION.txt NEWS.txt README.txt
%{python_sitearch}/*

%files -n %{name}-doc
%doc docs/fastcluster.pdf

%changelog
* Thu Jan 30 2020 Todd R <toddrme2178@gmail.com>
- update to version 1.1.26:
  * Small updates for Python 3.8.
* Mon Sep 17 2018 Arun Persaud <arun@gmx.de>
- update to version 1.1.25:
  * Removed all “#pragma GCC diagnostic” directives in .cpp files due
    to changed CRAN requirements (CRAN repository only, not the GitHub
    repository).
* Wed Jul 18 2018 tchvatal@suse.com
- Stricten version requirements on numpy to >= 1.9
* Sat Nov  4 2017 arun@gmx.de
- update to version 1.1.24:
  * R 3.5 corrects the formula for the “Canberra” metric. See
    https://bugs.r-project.org/bugzilla/show_bug.cgi?id=17285.
    The formula in the fastcluster package was changed accordingly. This
    concerns only the R interface. SciPy and fastcluster's Python interface
    always had the correct formula.
* Thu May  4 2017 toddrme2178@gmail.com
- Update to Version 1.1.23
  * setup.py: Late NumPy import for better dependency management.
- Update to Version 1.1.22
  * No fenv header usage if software floating-point emulation is used (bug
    report: NaN test failed on Debian armel).
- Implement single-spec version.
* Sun Oct 30 2016 jengelh@inai.de
- Update descriptions. Drop authorship and irrelevant future notes.
* Fri Oct 28 2016 toddrme2178@gmail.com
- Update to version 1.1.21:
  * Appropiate use of std namespace
- Update to version 1.1.20:
  * New version number due to PyPI upload error.
- Update to version 1.1.19:
  * Fixed unit tests. They can be run with "python setup.py test" now.
- Update to version 1.1.18:
  * Fixed missing NumPy header include path.
- Update to version 1.1.17:
  * Resolved MSVC compiler warnings.
- Update to version 1.1.16:
  * Support for large distance matrices (more than 2^31 entries, R's long
    vector support since version 3.0.0).
- Update to version 1.1.15:
  * Fixed the unit test to work with old and new R versions (see the changes
    in stats::hclust in R 3.1.0).
- Update to version 1.1.14:
  * Updated the DESCRIPTION file according to CRAN rules.
  * Renamed the "ward" method for dissimilarity input to "ward.D" in the R
    interface and created a new method "ward.D2", following changes in R's
    hclust package.
* Fri Nov 28 2014 toddrme2178@gmail.com
- Initial version
